@@ -2,21 +2,23 @@ extern crate proc_macro;
 
 use proc_macro::TokenStream;
 use quote::quote;
-use syn::{parse, parse2, DeriveInput, Ident};
-// use syn::parse::{Parse, ParseStream};
-// use syn::Result;
+use syn::parse::{Parse, ParseStream};
+use syn::{parenthesized, parse, parse2, DeriveInput, Ident, Result};
 
-// struct ServerStruct {
-//     name: Ident,
-// }
+struct ServerStruct {
+    name: Ident,
+}
 
-// impl Parse for ServerStruct {
-//     fn parse(input: ParseStream) -> Result<Self> {
-//         Ok(ServerStruct {
-//             name: input.parse()?,
-//         })
-//     }
-// }
+impl Parse for ServerStruct {
+    fn parse(input: ParseStream) -> Result<Self> {
+        let content;
+        parenthesized!(content in input);
+
+        Ok(ServerStruct {
+            name: content.parse()?,
+        })
+    }
+}
 
 #[proc_macro_derive(Server, attributes(struct_name))]
 pub fn checkout_server_derive(input: TokenStream) -> TokenStream {
@@ -36,11 +38,9 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
         .nth(0)
         .expect("struct_name attribute required to derive Server. This should be the name of the struct where ContextProvider is implemented");
 
-    // let server_struct: ServerStruct = parse2(server_struct_attribute.tokens.clone()).expect("invalid struct_name");
-    // let server_struct_name = &server_struct.name;
-
-    let server_struct_name: Ident =
+    let server_struct: ServerStruct =
         parse2(server_struct_attribute.tokens.clone()).expect("invalid struct_name");
+    let server_struct_name = &server_struct.name;
 
     let gen = quote! {
         mod checkout_server {
